@@ -97,18 +97,22 @@ class DriverPool:
 
     @staticmethod
     def _get_url(driver: Driver, request: SeleniumRequest) -> HtmlResponse:
-        web_driver = driver.web_driver
-        if request.driver is None:
-            web_driver.get(request.url)
-        if request.driver_func is not None:
-            func_res = request.driver_func(web_driver,
-                                           *request.driver_func_args,
-                                           **request.driver_func_kwargs)
-            if func_res:
-                request.meta['driver_func_res'] = func_res
-        body = to_bytes(web_driver.page_source)  # body must be of type bytes
-        response = HtmlResponse(web_driver.current_url, body=body, encoding='utf-8', request=request)
-        response.meta['driver'] = driver
+        response = None
+        try:
+            web_driver = driver.web_driver
+            if request.driver is None:
+                web_driver.get(request.url)
+            if request.driver_func is not None:
+                func_res = request.driver_func(web_driver,
+                                               *request.driver_func_args,
+                                               **request.driver_func_kwargs)
+                if func_res:
+                    request.meta['driver_func_res'] = func_res
+            body = to_bytes(web_driver.page_source)  # body must be of type bytes
+            response = HtmlResponse(web_driver.current_url, body=body, encoding='utf-8', request=request)
+            response.meta['driver'] = driver
+        except Exception as e:
+            logger.error(f'Error was happened in webdriver: {e}')
         return response
 
     @staticmethod
